const mysql = require('mysql2/promise');
const crypto = require('crypto');
const config = require('../config');
const logger = require('../utils/logger');

class Database {
    constructor() {
        this.pool = mysql.createPool(config.database);
        this.testConnection();
    }

    async testConnection() {
        try {
            const connection = await this.pool.getConnection();
            logger.info('Database connected successfully');
            connection.release();
        } catch (error) {
            logger.error('Database connection failed:', error);
            throw error;
        }
    }

    generateHash(content) {
        return crypto.createHash('sha256')
            .update(content.trim())
            .digest('hex');
    }

    async getSummary(articleUrl) {
        try {
            const [rows] = await this.pool.execute(
                'SELECT * FROM summaries WHERE article_url = ?',
                [articleUrl]
            );
            return rows[0] || null;
        } catch (error) {
            logger.error('Error getting summary:', error);
            throw error;
        }
    }

    async saveSummary(articleUrl, contentHash, summary) {
        try {
            const [result] = await this.pool.execute(`
                INSERT INTO summaries (article_url, content_hash, summary)
                VALUES (?, ?, ?)
                ON DUPLICATE KEY UPDATE
                    content_hash = VALUES(content_hash),
                    summary = VALUES(summary),
                    updated_at = CASE 
                        WHEN content_hash != VALUES(content_hash) 
                        THEN CURRENT_TIMESTAMP 
                        ELSE updated_at 
                    END
            `, [articleUrl, contentHash, summary]);

            return {
                articleUrl,
                contentHash,
                summary,
                isUpdate: result.affectedRows > 0 && result.affectedRows < 2
            };
        } catch (error) {
            logger.error('Error saving summary:', error);
            throw error;
        }
    }

    // 获取文章的更新历史（如果需要的话）
    async getArticleHistory(articleUrl) {
        try {
            const [rows] = await this.pool.execute(
                `SELECT content_hash, content, summary, updated_at 
                 FROM summaries 
                 WHERE article_url = ?
                 ORDER BY updated_at DESC`,
                [articleUrl]
            );
            return rows;
        } catch (error) {
            logger.error('Error getting article history:', error);
            throw error;
        }
    }
}

module.exports = new Database();